==> cscec5b-fbxt-api-3.0.1-20211203.042743-20-sources.jar: com/ejianc/business/fbxt/odd/vo/OddDetailVO.java <==
package com.ejianc.business.fbxt.odd.vo;

import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 零星用工明细表VO
 *
 * @author generator
 *
 */

public class OddDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long orgId;                // 组织
    private String cropName;           // 所属公司
    private String projectName;       // 项目名称
    private String billCode;          // 单据编号
    private String contractCode;      // 合同编号
    private String contractName;      // 合同名称
    private String supplierName;      // 施工单位

    private String createName;        // 编制人
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date createDate;          // 上报日期
    private String usetime;           // 用工日期
    private String usebegintime;           // 开始用工时间
    private String useendtime;             // 结束用工时间
    private String useType;             // 用工类型
    private String belong;              // 费用归属
    private java.math.BigDecimal price; // 单价

    private java.math.BigDecimal num;   // 数量
    private java.math.BigDecimal mny;   // 金额
    private java.math.BigDecimal reviewPrice; // 审核单价
    private java.math.BigDecimal reviewNum;   // 审核数量
    private java.math.BigDecimal reviewMny;   // 审核金额

    private String zkcontractName;      // 转扣合同
    private String redirectcorp;        // 转扣单位
    private java.math.BigDecimal zkmny;  // 转扣金额
    private Integer billState;            // 单据状态
    private Integer settleNcFlag;         // 结算状态  0-NC未结算，1-NC已结算

    private String  billStateName;        // 单据状态名称
    private String  settleNcFlagName;     // 结算状态名称
    private String  useTypeName;         // 用工类型名称
    private String  belongName;           // 费用归属名称

    private String  useDesc;              // 用工内容
    private String  name;                 // 用工项
    private String  infoUnit;             // 用工单位

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getCropName() {
        return cropName;
    }

    public void setCropName(String cropName) {
        this.cropName = cropName;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getUsetime() {
        return usetime;
    }

    public void setUsetime(String usetime) {
        this.usetime = usetime;
    }

    public String getUsebegintime() {
        return usebegintime;
    }

    public void setUsebegintime(String usebegintime) {
        this.usebegintime = usebegintime;
    }

    public String getUseendtime() {
        return useendtime;
    }

    public void setUseendtime(String useendtime) {
        this.useendtime = useendtime;
    }

    public String getUseType() {
        return useType;
    }

    public void setUseType(String useType) {
        this.useType = useType;
    }

    public String getBelong() {
        return belong;
    }

    public void setBelong(String belong) {
        this.belong = belong;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }

    public BigDecimal getReviewPrice() {
        return reviewPrice;
    }

    public void setReviewPrice(BigDecimal reviewPrice) {
        this.reviewPrice = reviewPrice;
    }

    public BigDecimal getReviewNum() {
        return reviewNum;
    }

    public void setReviewNum(BigDecimal reviewNum) {
        this.reviewNum = reviewNum;
    }

    public BigDecimal getReviewMny() {
        return reviewMny;
    }

    public void setReviewMny(BigDecimal reviewMny) {
        this.reviewMny = reviewMny;
    }

    public String getZkcontractName() {
        return zkcontractName;
    }

    public void setZkcontractName(String zkcontractName) {
        this.zkcontractName = zkcontractName;
    }

    public String getRedirectcorp() {
        return redirectcorp;
    }

    public void setRedirectcorp(String redirectcorp) {
        this.redirectcorp = redirectcorp;
    }

    public BigDecimal getZkmny() {
        return zkmny;
    }

    public void setZkmny(BigDecimal zkmny) {
        this.zkmny = zkmny;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Integer getSettleNcFlag() {
        return settleNcFlag;
    }

    public void setSettleNcFlag(Integer settleNcFlag) {
        this.settleNcFlag = settleNcFlag;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public String getSettleNcFlagName() {
        return settleNcFlagName;
    }

    public void setSettleNcFlagName(String settleNcFlagName) {
        this.settleNcFlagName = settleNcFlagName;
    }

    public String getUseTypeName() {
        return useTypeName;
    }

    public void setUseTypeName(String useTypeName) {
        this.useTypeName = useTypeName;
    }

    public String getBelongName() {
        return belongName;
    }

    public void setBelongName(String belongName) {
        this.belongName = belongName;
    }

    public String getUseDesc() {
        return useDesc;
    }

    public void setUseDesc(String useDesc) {
        this.useDesc = useDesc;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getInfoUnit() {
        return infoUnit;
    }

    public void setInfoUnit(String infoUnit) {
        this.infoUnit = infoUnit;
    }
}

==> cscec5b-fbxt-api-3.0.1-20220228.021628-49-sources.jar: com/ejianc/business/fbxt/odd/vo/OddDetailVO.java <==
package com.ejianc.business.fbxt.odd.vo;

import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 零星用工明细表VO
 *
 * @author generator
 *
 */

public class OddDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long orgId;                // 组织
    private String cropId;           // 所属公司主键
    private String cropName;           // 所属公司1
    private String projectName;       // 项目名称
    private String billCode;          // 单据编号
    private String contractCode;      // 合同编号
    private String contractName;      // 合同名称
    private String supplierName;      // 施工单位

    private String createName;        // 编制人
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date createDate;          // 上报日期
    private String usetime;           // 用工日期
    private String usebegintime;           // 开始用工时间
    private String useendtime;             // 结束用工时间
    private String useType;             // 用工类型
    private String belong;              // 费用归属
    private String planBody;            // 用工部位
    private java.math.BigDecimal price; // 单价

    private java.math.BigDecimal num;   // 数量
    private java.math.BigDecimal mny;   // 金额
    private java.math.BigDecimal reviewPrice; // 审核单价
    private java.math.BigDecimal reviewNum;   // 审核数量
    private java.math.BigDecimal reviewMny;   // 审核金额

    private String zkcontractName;      // 转扣合同
    private String redirectcorp;        // 转扣单位
    private java.math.BigDecimal zkmny;  // 转扣金额
    private Integer billState;            // 单据状态
    private Integer settleNcFlag;         // 结算状态  0-NC未结算，1-NC已结算

    private String  billStateName;        // 单据状态名称
    private String  settleNcFlagName;     // 结算状态名称
    private String  useTypeName;         // 用工类型名称
    private String  belongName;           // 费用归属名称

    private String  useDesc;              // 用工内容
    private String  name;                 // 用工项
    private String  infoUnit;             // 用工单位

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getCropId() {
        return cropId;
    }

    public void setCropId(String cropId) {
        this.cropId = cropId;
    }

    public String getCropName() {
        return cropName;
    }

    public void setCropName(String cropName) {
        this.cropName = cropName;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getUsetime() {
        return usetime;
    }

    public void setUsetime(String usetime) {
        this.usetime = usetime;
    }

    public String getUsebegintime() {
        return usebegintime;
    }

    public void setUsebegintime(String usebegintime) {
        this.usebegintime = usebegintime;
    }

    public String getUseendtime() {
        return useendtime;
    }

    public void setUseendtime(String useendtime) {
        this.useendtime = useendtime;
    }

    public String getUseType() {
        return useType;
    }

    public void setUseType(String useType) {
        this.useType = useType;
    }

    public String getBelong() {
        return belong;
    }

    public void setBelong(String belong) {
        this.belong = belong;
    }

    public String getPlanBody() {
        return planBody;
    }

    public void setPlanBody(String planBody) {
        this.planBody = planBody;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }

    public BigDecimal getReviewPrice() {
        return reviewPrice;
    }

    public void setReviewPrice(BigDecimal reviewPrice) {
        this.reviewPrice = reviewPrice;
    }

    public BigDecimal getReviewNum() {
        return reviewNum;
    }

    public void setReviewNum(BigDecimal reviewNum) {
        this.reviewNum = reviewNum;
    }

    public BigDecimal getReviewMny() {
        return reviewMny;
    }

    public void setReviewMny(BigDecimal reviewMny) {
        this.reviewMny = reviewMny;
    }

    public String getZkcontractName() {
        return zkcontractName;
    }

    public void setZkcontractName(String zkcontractName) {
        this.zkcontractName = zkcontractName;
    }

    public String getRedirectcorp() {
        return redirectcorp;
    }

    public void setRedirectcorp(String redirectcorp) {
        this.redirectcorp = redirectcorp;
    }

    public BigDecimal getZkmny() {
        return zkmny;
    }

    public void setZkmny(BigDecimal zkmny) {
        this.zkmny = zkmny;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Integer getSettleNcFlag() {
        return settleNcFlag;
    }

    public void setSettleNcFlag(Integer settleNcFlag) {
        this.settleNcFlag = settleNcFlag;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public String getSettleNcFlagName() {
        return settleNcFlagName;
    }

    public void setSettleNcFlagName(String settleNcFlagName) {
        this.settleNcFlagName = settleNcFlagName;
    }

    public String getUseTypeName() {
        return useTypeName;
    }

    public void setUseTypeName(String useTypeName) {
        this.useTypeName = useTypeName;
    }

    public String getBelongName() {
        return belongName;
    }

    public void setBelongName(String belongName) {
        this.belongName = belongName;
    }

    public String getUseDesc() {
        return useDesc;
    }

    public void setUseDesc(String useDesc) {
        this.useDesc = useDesc;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getInfoUnit() {
        return infoUnit;
    }

    public void setInfoUnit(String infoUnit) {
        this.infoUnit = infoUnit;
    }
}
